// Code generated by protoc-gen-gogo. DO NOT EDIT.
// source: codes/codes.proto

/*
Package codes is a generated protocol buffer package.

It is generated from these files:
	codes/codes.proto

It has these top-level messages:
*/
package codes

import proto "github.com/gogo/protobuf/proto"
import fmt "fmt"
import math "math"
import _ "github.com/gogo/protobuf/gogoproto"

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.GoGoProtoPackageIsVersion2 // please upgrade the proto package

type Code int32

const (
	// OK is returned on success.
	OK Code = 0
	// Unknown error.
	Unknown Code = 1
	// Unimplemented indicates operation is not implemented or not
	// supported/enabled in this service.
	Unimplemented Code = 2
	// Internal errors.  Means some invariants expected by underlying
	// system has been broken.  If you see one of these errors,
	// something is very broken.
	Internal Code = 3
)

var Code_name = map[int32]string{
	0: "OK",
	1: "UNKNOWN",
	2: "UNIMPLEMETED",
	3: "INTERNAL",
}
var Code_value = map[string]int32{
	"OK":           0,
	"UNKNOWN":      1,
	"UNIMPLEMETED": 2,
	"INTERNAL":     3,
}

func (x Code) String() string {
	return proto.EnumName(Code_name, int32(x))
}
func (Code) EnumDescriptor() ([]byte, []int) { return fileDescriptorCodes, []int{0} }

func init() {
	proto.RegisterEnum("codes.Code", Code_name, Code_value)
}

func init() { proto.RegisterFile("codes/codes.proto", fileDescriptorCodes) }

var fileDescriptorCodes = []byte{
	// 219 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0x12, 0x4c, 0xce, 0x4f, 0x49,
	0x2d, 0xd6, 0x07, 0x93, 0x7a, 0x05, 0x45, 0xf9, 0x25, 0xf9, 0x42, 0xac, 0x60, 0x8e, 0x94, 0x6e,
	0x7a, 0x66, 0x49, 0x46, 0x69, 0x92, 0x5e, 0x72, 0x7e, 0xae, 0x7e, 0x7a, 0x7e, 0x7a, 0xbe, 0x3e,
	0x58, 0x36, 0xa9, 0x34, 0x0d, 0xcc, 0x03, 0x73, 0xc0, 0x2c, 0x88, 0x2e, 0xad, 0x72, 0x2e, 0x16,
	0xe7, 0xfc, 0x94, 0x54, 0x21, 0x3e, 0x2e, 0x26, 0x7f, 0x6f, 0x01, 0x06, 0x29, 0xb6, 0xae, 0xb9,
	0x0a, 0x4c, 0xfe, 0xde, 0x42, 0x12, 0x5c, 0xec, 0xa1, 0x7e, 0xde, 0x7e, 0xfe, 0xe1, 0x7e, 0x02,
	0x8c, 0x52, 0xdc, 0x5d, 0x73, 0x15, 0xd8, 0x43, 0xf3, 0xb2, 0xf3, 0xf2, 0xcb, 0xf3, 0x84, 0x94,
	0xb9, 0x78, 0x42, 0xfd, 0x3c, 0x7d, 0x03, 0x7c, 0x5c, 0x7d, 0x5d, 0x43, 0x5c, 0x5d, 0x04, 0x98,
	0xa4, 0x04, 0xbb, 0xe6, 0x2a, 0xf0, 0x86, 0xe6, 0x65, 0xe6, 0x16, 0xe4, 0xa4, 0xe6, 0xa6, 0xe6,
	0x95, 0xa4, 0xa6, 0x08, 0x49, 0x71, 0x71, 0x78, 0xfa, 0x85, 0xb8, 0x06, 0xf9, 0x39, 0xfa, 0x08,
	0x30, 0x4b, 0xf1, 0x74, 0xcd, 0x55, 0xe0, 0xf0, 0xcc, 0x2b, 0x49, 0x2d, 0xca, 0x4b, 0xcc, 0x91,
	0x62, 0xe9, 0x58, 0x2c, 0xc7, 0xe0, 0x24, 0x70, 0xe2, 0x91, 0x1c, 0xe3, 0x85, 0x47, 0x72, 0x8c,
	0x0f, 0x1e, 0xc9, 0x31, 0x4e, 0x78, 0x2c, 0xc7, 0x90, 0xc4, 0x06, 0x76, 0x91, 0x31, 0x20, 0x00,
	0x00, 0xff, 0xff, 0xd4, 0x54, 0x67, 0x0c, 0xdc, 0x00, 0x00, 0x00,
}
