syntax = "proto3";
package foo;

import "github.com/influxdata/yarpc/yarpcproto/yarpc.proto";

service Foo {
  option (yarpcproto.yarpc_service_index) = 0x00;

  rpc UnaryMethod(Request) returns (Response){
    option (yarpcproto.yarpc_method_index) = 0x00;
  }

  rpc ServerStreamMethod(Request) returns (stream Response){
    option (yarpcproto.yarpc_method_index) = 0x01;
  }
}

message Request {
  string in = 1;
}

message Response {
  string out = 1;
}

