syntax = "proto2";
package yarpcproto;

import "google/protobuf/descriptor.proto";

extend google.protobuf.ServiceOptions {
  optional uint32 yarpc_service_index = 50000;
}

extend google.protobuf.MethodOptions {
  optional uint32 yarpc_method_index = 50000;
}