syntax = "proto3";
package status;

import "github.com/gogo/protobuf/gogoproto/gogo.proto";
import "github.com/influxdata/yarpc/codes/codes.proto";

message Status {
  codes.Code code = 1;
  string message = 2;
}
