syntax = "proto3";
package codes;

import "github.com/gogo/protobuf/gogoproto/gogo.proto";

enum Code {
  option (gogoproto.goproto_enum_prefix) = false;

  // OK is returned on success.
  OK = 0 [(gogoproto.enumvalue_customname) = "OK"];

  // Unknown error.
  UNKNOWN = 1 [(gogoproto.enumvalue_customname) = "Unknown"];

  // Unimplemented indicates operation is not implemented or not
  // supported/enabled in this service.
  UNIMPLEMETED = 2 [(gogoproto.enumvalue_customname) = "Unimplemented"];

  // Internal errors.  Means some invariants expected by underlying
  // system has been broken.  If you see one of these errors,
  // something is very broken.
  INTERNAL = 3 [(gogoproto.enumvalue_customname) = "Internal"];
}
